@@ -9,6 +9,8 @@ from rich.text import Span, Text
 
 from wtfis.clients.abuseipdb import AbuseIpDbClient
 from wtfis.clients.greynoise import GreynoiseClient
+from wtfis.clients.ip2location import Ip2LocationClient
+from wtfis.clients.ipinfo import IpInfoClient
 from wtfis.clients.ipwhois import IpWhoisClient
 from wtfis.clients.shodan import ShodanClient
 from wtfis.clients.urlhaus import UrlHausClient
@@ -29,7 +31,7 @@ def view01(
     mock_greynoise_get,
     mock_urlhaus_get,
 ):
-    """1.1.1.1 with PT whois. Complete test of all panels. Also test print()."""
+    """1.1.1.1 with default whois (VT). Complete test of all panels. Also test print()."""
     ip = "1.1.1.1"
 
     geoasn_pool = json.loads(test_data("ipwhois_1.1.1.1.json"))
@@ -61,7 +63,7 @@ def view01(
     abuseipdb_enrich = abuseipdb_client.enrich_ips(ip)
 
     urlhaus_pool = json.loads(test_data("urlhaus_1.1.1.1.json"))
-    urlhaus_client = UrlHausClient()
+    urlhaus_client = UrlHausClient("dummykey")
     urlhaus_client._get_host = MagicMock(
         side_effect=lambda ip: mock_urlhaus_get(ip, urlhaus_pool)
     )
@@ -244,6 +246,52 @@ def view08(test_data, mock_abuseipdb_get):
     )
 
 
+@pytest.fixture()
+def view09(test_data, mock_ip2location_get):
+    """1.1.1.1 with IP2Location. Test the IP2Location only."""
+    ip = "1.1.1.1"
+    geoasn_pool = json.loads(test_data("ip2location_1.1.1.1.json"))
+    geoasn_client = Ip2LocationClient("dummykey")
+    geoasn_client._get_ip2location = MagicMock(
+        side_effect=lambda ip: mock_ip2location_get(ip, geoasn_pool)
+    )
+    geoasn_enrich = geoasn_client.enrich_ips(ip)
+
+    return IpAddressView(
+        console=Console(),
+        entity=IpAddress.model_validate(json.loads(test_data("vt_ip_1.1.1.1.json"))),
+        geoasn=geoasn_enrich,
+        whois=MagicMock(),
+        shodan=MagicMock(),
+        greynoise=MagicMock(),
+        abuseipdb=MagicMock(),
+        urlhaus=MagicMock(),
+    )
+
+
+@pytest.fixture()
+def view10(test_data, mock_ipinfo_get):
+    """1.1.1.1 with IPInfo. Test IPInfo only."""
+    ip = "1.1.1.1"
+    geoasn_pool = json.loads(test_data("ipinfo_1.1.1.1.json"))
+    geoasn_client = IpInfoClient()
+    geoasn_client._get_ipinfo = MagicMock(
+        side_effect=lambda ip: mock_ipinfo_get(ip, geoasn_pool)
+    )
+    geoasn_enrich = geoasn_client.enrich_ips(ip)
+
+    return IpAddressView(
+        console=Console(),
+        entity=IpAddress.model_validate(json.loads(test_data("vt_ip_1.1.1.1.json"))),
+        geoasn=geoasn_enrich,
+        whois=MagicMock(),
+        shodan=MagicMock(),
+        greynoise=MagicMock(),
+        abuseipdb=MagicMock(),
+        urlhaus=MagicMock(),
+    )
+
+
 class TestView01:
     def test_ip_panel(self, view01, theme, display_timestamp):
         ip = view01.ip_panel()
@@ -326,6 +374,7 @@ class TestView01:
             "ASN:",
             "ISP:",
             "Location:",
+            "Domain:",
         ]
         assert table.columns[1].style == theme.table_value
         assert table.columns[1].justify == "left"
@@ -342,6 +391,7 @@ class TestView01:
                     Span(23, 25, "default"),
                 ],
             ),
+            "cloudflare.com",
         ]
 
         #
@@ -681,6 +731,7 @@ class TestView02:
             "ASN:",
             "ISP:",
             "Location:",
+            "Domain:",
         ]
         assert table.columns[1].style == theme.table_value
         assert table.columns[1].justify == "left"
@@ -694,6 +745,7 @@ class TestView02:
                 "Sydney, New South Wales, Australia",
                 spans=[Span(6, 8, "default"), Span(23, 25, "default")],
             ),
+            "cloudflare.com",
         ]
 
         #
@@ -998,3 +1050,41 @@ class TestAbuseIpDbOnly:
                 Span(19, 33, theme.table_value),
             ],
         )
+
+
+class TestIP2LocationOnly:
+    def test_ip_panel(self, view09):
+        ip = view09.ip_panel()
+
+        ip2location_section = ip.renderable.renderables[2]
+
+        # Title
+        assert ip2location_section.renderables[0] == Text("IP2Location")
+
+        # Table
+        table = ip2location_section.renderables[1]
+        assert str(table.columns[0]._cells[0]) == "ASN:"
+        assert str(table.columns[0]._cells[1]) == "Location:"
+        assert str(table.columns[0]._cells[2]) == "Proxy:"
+        assert str(table.columns[1]._cells[0]) == "13335 (CloudFlare Inc.)"
+        assert str(table.columns[1]._cells[1]) == "Brisbane, Queensland, Australia"
+        assert str(table.columns[1]._cells[2]) == "False"
+
+
+class TestIPInfoOnly:
+    def test_ip_panel(self, view10):
+        ip = view10.ip_panel()
+
+        ipinfo_section = ip.renderable.renderables[2]
+
+        # Table
+        table = ipinfo_section.renderables[1]
+        assert len(table.columns[0]._cells) == 4
+        assert str(table.columns[0]._cells[0]) == "ASN:"
+        assert str(table.columns[0]._cells[1]) == "Location:"
+        assert str(table.columns[0]._cells[2]) == "Hostname:"
+        assert str(table.columns[0]._cells[3]) == "Anycast:"
+        assert str(table.columns[1]._cells[0]) == "13335 (Cloudflare, Inc.)"
+        assert str(table.columns[1]._cells[1]) == "Brisbane, Queensland, AU"
+        assert str(table.columns[1]._cells[2]) == "one.one.one.one"
+        assert str(table.columns[1]._cells[3]) == "True"
